@@ -21,14 +21,13 @@
 #include <KAboutData>
 #include <KLocalizedString>
 
-#include <config-kig.h>
+#include <kig_version.h>
 
 inline KAboutData kigAboutData( const char* name, const char* iname )
 {
-  const char* version = "v" KIGVERSION;
   const char* description = I18N_NOOP( "KDE Interactive Geometry" );
 
-  KAboutData tmp( name, i18n(iname), version,
+  KAboutData tmp( name, i18n(iname), KIG_VERSION_STRING,
 				   i18n(description), KAboutLicense::GPL,
 				   i18n( "(C) 2002-2005, The Kig developers" ),
 				   QString(), QStringLiteral("http://edu.kde.org/kig") );
